@@ -21,25 +21,27 @@ __all__ = ["XRSClient", "SUVIClient"]
 
 class XRSClient(GenericClient):
     """
-    Provides access to the GOES XRS fits files archive.
+    Provides access to several GOES XRS files archive.
 
-    Searches for GOES XRS data both on NASA servers prior to re-processed
-    GOES 13, 14 and 15 and on the NOAA archive for > GOES 13.
-    For satellite numbers > 13 the XRSClient searches the NOAA archive, and
-    returns the re-processed science-quality data for GOES 13, 14 and 15, and
-    also the new GOES-R series 16 and 17.
+    For older GOES satellites (7 and below), NASA servers are used.
+    For newer GOES satellites (8 and above), NOAA servers are used.
 
-    Note - the new science quality data have scaling factors removed for 13, 14 and 15
-    and they are not added to GOES 16 AND 17. This means the peak flux will be different to
-    the older version of the data, such as those collected from the NASA servers.
+    For GOES 8-15, the data is the re-processed science-quality data.
 
-    See the following readmes about the data
+    .. note::
 
-    * Reprocessed 13, 14, 15 :
-        https://satdat.ngdc.noaa.gov/sem/goes/data/science/xrs/GOES_13-15_XRS_Science-Quality_Data_Readme.pdf
+        The new science quality data have the scaling factors removed for GOES 8-15
+        and they are not added to GOES 16 AND 17 data products.
+        This means the peak flux will be different to the older version of the data,
+        such as those collected from the NASA servers.
 
-    * GOES-R 16, 17 :
-        https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/goes16/l1b/docs/GOES-R_EXIS_XRS_L1b_Science-Quality_Data_ReadMe.pdf
+    See the following readmes about these data:
+
+    * GOES 1 - 7: https://umbra.nascom.nasa.gov/goes/fits/goes_fits_files_notes.txt
+
+    * Reprocessed 8 - 15: https://www.ncei.noaa.gov/data/goes-space-environment-monitor/access/science/xrs/GOES_1-15_XRS_Science-Quality_Data_Readme.pdf
+
+    * GOES-R 16 - 17: https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/goes16/l1b/docs/GOES-R_EXIS_XRS_L1b_Science-Quality_Data_ReadMe.pdf
 
     Examples
     --------
@@ -51,9 +53,9 @@ class XRSClient(GenericClient):
     Results from 1 Provider:
     <BLANKLINE>
     4 Results from the XRSClient:
-    Source: <13: https://umbra.nascom.nasa.gov/goes/fits
-    13, 14, 15: https://satdat.ngdc.noaa.gov/sem/goes/data/science/
-    16, 17: https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/
+    Source: <8: https://umbra.nascom.nasa.gov/goes/fits
+    8-15: https://www.ncei.noaa.gov/data/goes-space-environment-monitor/access/science/
+    16-17: https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/
     <BLANKLINE>
            Start Time               End Time        Instrument ... Source Provider
     ----------------------- ----------------------- ---------- ... ------ --------
@@ -63,18 +65,16 @@ class XRSClient(GenericClient):
     2016-01-02 00:00:00.000 2016-01-02 23:59:59.999        XRS ...   GOES     NOAA
     <BLANKLINE>
     <BLANKLINE>
-
     """
-    # GOES XRS data from NASA servers up to GOES 15.
-    # The reprocessed 13, 14, 15 data should be taken from NOAA server.
+    # GOES XRS data from NASA servers up to GOES 7.
     baseurl_old = r'https://umbra.nascom.nasa.gov/goes/fits/%Y/go(\d){2}(\d){6,8}\.fits'
     pattern_old = '{}/fits/{year:4d}/go{SatelliteNumber:02d}{}{month:2d}{day:2d}.fits'
-    # GOES XRS 13, 14, 15 from NOAA (re-processed data)
-    baseurl_new = (r"https://satdat.ngdc.noaa.gov/sem/goes/data/science/xrs/"
-                   r"goes{SatelliteNumber}/gxrs-l2-irrad_science/%Y/%m/sci_gxrs-l2-irrad_g{SatelliteNumber}_d%Y%m%d_.*\.nc")
+    # The reprocessed 8-15 data should be taken from NOAA.
+    baseurl_new = (r"https://www.ncei.noaa.gov/data/goes-space-environment-monitor/access/science/xrs/"
+                   r"goes{SatelliteNumber:02d}/gxrs-l2-irrad_science/%Y/%m/sci_gxrs-l2-irrad_g{SatelliteNumber:02d}_d%Y%m%d_.*\.nc")
     pattern_new = ("{}/goes{SatelliteNumber:02d}/gxrs-l2-irrad_science/{year:4d}/"
                    "{month:2d}/sci_gxrs-l2-irrad_g{SatelliteNumber:02d}_d{year:4d}{month:2d}{day:2d}_{}.nc")
-    # GOES XRS data for GOES-R Series - 16, 17
+    # GOES-R Series 16-17 XRS data from NOAA.
     baseurl_r = (r"https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/goes{SatelliteNumber}"
                  r"/l2/data/xrsf-l2-flx1s_science/%Y/%m/sci_xrsf-l2-flx1s_g{SatelliteNumber}_d%Y%m%d_.*\.nc")
     pattern_r = ("{}/goes/goes{SatelliteNumber:02d}/l2/data/xrsf-l2-flx1s_science/{year:4d}/"
@@ -82,9 +82,9 @@ class XRSClient(GenericClient):
 
     @property
     def info_url(self):
-        return ("<13: https://umbra.nascom.nasa.gov/goes/fits \n"
-                "13, 14, 15: https://satdat.ngdc.noaa.gov/sem/goes/data/science/ \n"
-                "16, 17: https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/")
+        return ("<8: https://umbra.nascom.nasa.gov/goes/fits \n"
+                "8-15: https://www.ncei.noaa.gov/data/goes-space-environment-monitor/access/science/ \n"
+                "16-17: https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/")
 
     def post_search_hook(self, i, matchdict):
         tr = get_timerange_from_exdict(i)
@@ -102,16 +102,15 @@ class XRSClient(GenericClient):
             rowdict["Provider"] = matchdict["Provider"][0]
         else:
             rowdict["Provider"] = matchdict["Provider"][1]
-
         return rowdict
 
     def search(self, *args, **kwargs):
         matchdict = self._get_match_dict(*args, **kwargs)
         # this is for the case when the timerange overlaps with the provider change.
-        if matchdict["Start Time"] < "2009-09-01" and matchdict["End Time"] >= "2009-09-01":
+        if matchdict["Start Time"] < "2001-03-01" and matchdict["End Time"] >= "2001-03-01":
             matchdict_before, matchdict_after = matchdict.copy(), matchdict.copy()
-            matchdict_after["Start Time"] = parse_time('2009-09-01')
-            matchdict_before["End Time"] = parse_time('2009-08-31')
+            matchdict_after["Start Time"] = parse_time('2001-03-01')
+            matchdict_before["End Time"] = parse_time('2001-03-01')
             metalist_before = self._get_metalist(matchdict_before)
             metalist_after = self._get_metalist(matchdict_after)
             metalist = metalist_before + metalist_after
@@ -139,17 +138,17 @@ class XRSClient(GenericClient):
         This makes it easier for when searching for overlapping providers.
         """
         metalist = []
-        # the data before the re-processed GOES 13, 14, 15 data.
-        if (matchdict["End Time"] < "2009-09-01") or (matchdict["End Time"] >= "2009-09-01" and matchdict["Provider"] == ["sdac"]):
+        # The data before the re-processed GOES 8-15 data.
+        if (matchdict["End Time"] < "2001-03-01") or (matchdict["End Time"] >= "2001-03-01" and matchdict["Provider"] == ["sdac"]):
             metalist += self._get_metalist_fn(matchdict, self.baseurl_old, self.pattern_old)
-        # new data from NOAA.
+        # New data from NOAA.
         else:
             if matchdict["End Time"] >= "2017-02-07":
                 for sat in [16, 17]:
                     metalist += self._get_metalist_fn(matchdict,
                                                       self.baseurl_r.format(SatelliteNumber=sat), self.pattern_r)
             if matchdict["End Time"] <= "2020-03-04":
-                for sat in [13, 14, 15]:
+                for sat in [8, 9, 10, 11, 12, 13, 14, 15]:
                     metalist += self._get_metalist_fn(matchdict,
                                                       self.baseurl_new.format(SatelliteNumber=sat), self.pattern_new)
         return metalist
@@ -170,7 +169,6 @@ class XRSClient(GenericClient):
             attrs.Provider: [('SDAC', 'The Solar Data Analysis Center.'),
                              ('NOAA', 'The National Oceanic and Atmospheric Administration.')],
             attrs.goes.SatelliteNumber: [(str(x), f"GOES Satellite Number {x}") for x in goes_number]}
-
         return adict
 
 
@@ -178,21 +176,16 @@ class SUVIClient(GenericClient):
     """
     Provides access to data from the GOES Solar Ultraviolet Imager (SUVI).
 
-    SUVI data are provided by NOAA at the following url
-    https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/
-    The SUVI instrument was first included on GOES-16. It produces level-1b as
-    well as level-2 data products. Level-2 data products are a weighted average
-    of level-1b product files and therefore provide higher imaging dynamic
-    range than individual images. The exposure time of level 1b images range
-    from 1 s to 0.005 s. SUVI supports the following wavelengths;
-    94, 131, 171, 195, 284, 304 angstrom. If no wavelength is specified, images
-    from all wavelengths are returned.
+    `SUVI data are provided by NOAA <https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/>`__.
 
-    Note
-    ----
-    GOES-16 began providing regular level-1b data on 2018-06-01.  At the time
-    of writing, SUVI on GOES-17 is operational but currently does not provide
-    Level-2 data.
+    The SUVI instrument was first included on GOES-16. It produces level 1b as
+    well as level-2 data products. Level 2 data products are a weighted average
+    of level 1b product files and therefore provide higher imaging dynamic
+    range than individual images. The exposure time of level 1b images range
+    from 1 s to 0.005 s.
+
+    SUVI supports the following wavelengths; 94, 131, 171, 195, 284, 304 angstrom.
+    If no wavelength is specified, images from all wavelengths are returned.
 
     Examples
     --------
@@ -215,7 +208,6 @@ class SUVIClient(GenericClient):
     2020-07-10 00:08:00.000 2020-07-10 00:12:00.000       SUVI ...     2      304.0
     <BLANKLINE>
     <BLANKLINE>
-
     """
     baseurl1b = (r'https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes/goes'
                  r'{SatelliteNumber}/l1b/suvi-l1b-{elem:2}{wave:03}/%Y/%m/%d/OR_SUVI-L1b.*\.fits.gz')
@@ -233,8 +225,7 @@ class SUVIClient(GenericClient):
         return 'https://data.ngdc.noaa.gov/platforms/solar-space-observing-satellites/goes'
 
     def post_search_hook(self, i, matchdict):
-
-        # extracting start times and end times
+        # Extracting start times and end times
         start = Time(datetime(i['year'], i['month'], i['day'], i['hour'], i['minute'], i['second']))
         start.format = 'iso'
         end = Time(datetime(i['year'], i['month'], i['day'], i['ehour'], i['eminute'], i['esecond']))
@@ -306,7 +297,7 @@ class SUVIClient(GenericClient):
     @classmethod
     def register_values(cls):
         from sunpy.net import attrs
-        goes_number = [16, 17]
+        goes_number = [16, 17, 18]
         adict = {attrs.Instrument: [
             ("SUVI", "GOES Solar Ultraviolet Imager.")],
             attrs.goes.SatelliteNumber: [(str(x), f"GOES Satellite Number {x}") for x in goes_number],
